@@ -1,12 +1,13 @@
 """Hypothesis plugin"""
 
+import inspect
 import typing
 
+import pydantic
 import typing_extensions
 import hypothesis.strategies as st
 
 from .href import Href
-from .model import BaseReferrableModel
 
 
 def _hrefs_strategy(model_type: typing.Type[Href]):
@@ -14,14 +15,23 @@ def _hrefs_strategy(model_type: typing.Type[Href]):
     if len(args) != 1:
         raise ValueError("Cannot create strategy for plain Href")
     referrable_type = args[0]
-    if not issubclass(referrable_type, BaseReferrableModel):
+    try:
+        key_model = getattr(referrable_type, "_key_model", None)
+        if not key_model:
+            return_annotation = inspect.signature(
+                referrable_type.url_to_key
+            ).return_annotation
+            key_model = pydantic.create_model(
+                "_key_model", __root__=(return_annotation, ...)
+            )
+    except Exception as ex:
         raise ValueError(
             f"Cannot create strategy for Href[{referrable_type.__name__}]: "
-            f"{referrable_type.__name__} is not subclass of BaseReferrableModel"
-        )
+            f"could not determine key model for {referrable_type.__name__ }"
+        ) from ex
     return (
-        st.builds(referrable_type._key_model)  # pylint: disable=protected-access
-        .map(lambda key_model: key_model.__root__)  # type: ignore
+        st.from_type(key_model)
+        .map(lambda key_model: key_model.__root__)
         .map(lambda key: Href(key=key, url=referrable_type.key_to_url(key)))
     )
 
